︠f50d0063-7a49-44cc-bcd2-3fbf0cb5b1a0i︠
%md
# Tangent Lines
In your experience with mathematics thus far, you have most likely come across the task of calculating the slope between two points. Whether you know it as "rise over run" or "change in y over change in x", the formula

#### $\dfrac{y_2-y_1}{x_2-x_1}$

will give you the slope between points $(x_1, y_1)$ and $(x_2, y_2)$. So if, for instance, we were to calculate the slope between two points on $f(x) = \dfrac{x^3}{2}$, say $(0, 0)$ and $(2, 4)$, we would find that by the formula, $\dfrac{4 - 0}{2 - 0}$ gives us a slope of $2$, as pictured on the following graph. For a purpose that will later be revealed, however, what if we were to find the slope of the function at a single point -- at $(1, \dfrac{1}{2})$? Such is the nature of the tangent line problem that we are about to explore, and is one of the basic questions of calculus.

Rather than simply generating a static graph this time, we'll be doing a bit of manipulation. It is highly recommended that you follow along. In a new worksheet called 06-Tangent Lines, copy/paste the following code and evaluate it.
︡f47cab7c-2646-43b9-8b8b-dd6e9b6a8430︡︡{"done":true,"md":"# Tangent Lines\nIn your experience with mathematics thus far, you have most likely come across the task of calculating the slope between two points. Whether you know it as \"rise over run\" or \"change in y over change in x\", the formula\n\n#### $\\dfrac{y_2-y_1}{x_2-x_1}$\n\nwill give you the slope between points $(x_1, y_1)$ and $(x_2, y_2)$. So if, for instance, we were to calculate the slope between two points on $f(x) = \\dfrac{x^3}{2}$, say $(0, 0)$ and $(2, 4)$, we would find that by the formula, $\\dfrac{4 - 0}{2 - 0}$ gives us a slope of $2$, as pictured on the following graph. For a purpose that will later be revealed, however, what if we were to find the slope of the function at a single point -- at $(1, \\dfrac{1}{2})$? Such is the nature of the tangent line problem that we are about to explore, and is one of the basic questions of calculus.\n\nRather than simply generating a static graph this time, we'll be doing a bit of manipulation. It is highly recommended that you follow along. In a new worksheet called 06-Tangent Lines, copy/paste the following code and evaluate it."}
︠65747d9a-0d53-4edf-9208-a1847dee97e1s︠
x1 = 0       # Declare x values of interest
x2 = 2

def f(x):    # Define quadratic function
    return (x^3)/2

y1 = f(x1)   # Solve for y values of quadratic at given x values
y2 = f(x2)

slope = (y2-y1)/(x2-x1)    # Define slope that passes through points of interest

p = plot(f(x), x, 0, 3)    # Generate a plot of the quadratic function, and points of interest
pt1 = point((x1, y1), rgbcolor=(1,0,0), pointsize=30)
pt2 = point((x2, y2), rgbcolor=(1,0,0), pointsize=30)

d = 3                      # Generate a line that passes through
l = line([(x1-d, y1-d*slope), (x2+d, y2+d*slope)], rgbcolor=(1,0,0))

t1 = text("(%s, %s)" % (float(x1), float(y1)), (x1+0.5, y1-0.8), rgbcolor=(1,0,0)) # Generate labels
t2 = text("(%s, %s)" % (float(x2), float(y2)), (x2+0.5, y2-0.8), rgbcolor=(1,0,0))
t3 = text("slope: %s" % float(slope), ((x1+x2)/2-0.5, (y1+y2)/2), rgbcolor=(1,0,0))

g = p+pt1+pt2+l+t1+t2+t3   # Combine and show previously generated graphs and points with given bounds
g.show(xmin=0, xmax=3, ymin=-1, ymax=9)
︡cf73067c-22ac-42f9-8403-cb657db3b826︡︡{"once":false,"done":false,"file":{"show":true,"uuid":"1b0400bc-8e18-4886-9c99-2106d9d92628","filename":"/projects/c71ef2fe-f1b2-482d-ab29-c91dba1e241a/.sage/temp/compute3-us/551/tmp_QH333D.svg"}}︡{"html":"<div align='center'></div>","done":false}︡{"done":true}
︠15449329-d514-48d6-a6f8-a145061ba7d8i︠
%md
 In the graph, the straight line that passes through the two points is called a **secant** line -- we can say that it is an approximation of the function's slope at the point $(1, \dfrac{1}{2})$, albeit not a very good one. What we want is a line **tangent** to the function at $(1, \dfrac{1}{2})$ -- one that has a slope equal to that of the function at $(1, \dfrac{1}{2})$.

To attain a better approximation of the slope at that point, let's try decreasing the distance between the two points at either side of it. In the first cell of your worksheet, change $x_1$ to $0.5$ and $x_2$ to $1.5$ and evaluate. Your graph should now look something like the following:
︡ab12ad2e-5e99-410e-9651-0ef81d734894︡︡{"done":true,"md":" In the graph, the straight line that passes through the two points is called a **secant** line -- we can say that it is an approximation of the function's slope at the point $(1, \\dfrac{1}{2})$, albeit not a very good one. What we want is a line **tangent** to the function at $(1, \\dfrac{1}{2})$ -- one that has a slope equal to that of the function at $(1, \\dfrac{1}{2})$.\n\nTo attain a better approximation of the slope at that point, let's try decreasing the distance between the two points at either side of it. In the first cell of your worksheet, change $x_1$ to $0.5$ and $x_2$ to $1.5$ and evaluate. Your graph should now look something like the following:"}
︠4cd6c161-ba92-4de9-85d8-641f1ee10ef7i︠
# State x values of interest
x1 = 0.5
x2 = 1.5

# Define quadratic function
def f(x):
    return (x^3)/2

# Find y values on quadratic at given x
y1 = f(x1)
y2 = f(x2)

# Define slope that passes through points of interest
slope = (y2-y1)/(x2-x1)

# Generate a plot of the quadratic function, and points of interest
p = plot(f(x), x, 0, 3)
pt1 = point((x1, y1), rgbcolor=(1,0,0), pointsize=30)
pt2 = point((x2, y2), rgbcolor=(1,0,0), pointsize=30)

# Generate a line that passes through
d = 3
l = line([(x1-d, y1-d*slope), (x2+d, y2+d*slope)], rgbcolor=(1,0,0))

# Generate labels
t1 = text("(%s, %s)" % (float(x1), float(y1)), (x1+0.5, y1-0.8), rgbcolor=(1,0,0))
t2 = text("(%s, %s)" % (float(x2), float(y2)), (x2+0.5, y2-0.8), rgbcolor=(1,0,0))
t3 = text("slope: %s" % float(slope), ((x1+x2)/2-0.5, (y1+y2)/2), rgbcolor=(1,0,0))

# Combine and show previously generated graphs and points with given bounds
g = p+pt1+pt2+l+t1+t2+t3
g.show(xmin=0, xmax=3, ymin=-1, ymax=9)
︡eae279cf-1cfb-4934-a04a-7025ce53166f︡︡{"once":false,"done":false,"file":{"show":true,"uuid":"86bb1c8c-a501-44b7-9099-aed98318d7e3","filename":"/projects/c71ef2fe-f1b2-482d-ab29-c91dba1e241a/.sage/temp/compute3-us/2552/tmp_JR8nOS.svg"}}︡{"html":"<div align='center'></div>","done":false}︡{"done":true}
︠bb998b22-2b73-497c-b51a-c3ae9f180b3bi︠
%md
 As you can see, the secant line in this graph still does not pass through the desired point of $(1, \dfrac{1}{2})$, but at least we are getting closer. Now, try setting $x_1$ as $0.999$ and $x_2$ as $1.001$ and again evaluate the cell. Aside from looking cramped, what else can you observe about this graph? Ah ha! you surely say, it looks like the slope at $(1, \dfrac{1}{2})$ is just about equal to $1.5000005$. We could, of course, repeat this process in perpetuum, since when only a billionth of a unit separates the two points, there is little doubt that the calculated slope does, in fact, approximately equal the slope of $f(x) = \dfrac{x^3}{2}$ at $(1, \dfrac{1}{2})$.

Let us skip that theoretical headache, however, and consider a much faster (and even more accurate!) method. Look again at the formula for calculating slopes, this time in a slightly altered form:

$\dfrac{f(x+h)-f(x)}{h}$
︡a879f946-e2a7-4f7d-9adc-445fcc17bf2b︡︡{"done":true,"md":" As you can see, the secant line in this graph still does not pass through the desired point of $(1, \\dfrac{1}{2})$, but at least we are getting closer. Now, try setting $x_1$ as $0.999$ and $x_2$ as $1.001$ and again evaluate the cell. Aside from looking cramped, what else can you observe about this graph? Ah ha! you surely say, it looks like the slope at $(1, \\dfrac{1}{2})$ is just about equal to $1.5000005$. We could, of course, repeat this process in perpetuum, since when only a billionth of a unit separates the two points, there is little doubt that the calculated slope does, in fact, approximately equal the slope of $f(x) = \\dfrac{x^3}{2}$ at $(1, \\dfrac{1}{2})$.\n\nLet us skip that theoretical headache, however, and consider a much faster (and even more accurate!) method. Look again at the formula for calculating slopes, this time in a slightly altered form:\n\n$\\dfrac{f(x+h)-f(x)}{h}$"}
︠6cac1d27-2889-4dd8-ab22-187382b5ec3fi︠
%md
Rather than ignoring the relationship between the two points, as in the first form, this formula relies upon it. The symbol $y_2$ is now $f(x + h)$, and $y_1$ is $f(x)$. The major difference here, though, is that $x_2$ has been replaced by the first $x$ plus some change "$h$". The slope formula's premise still stands, however, as the new form does in fact calculate change in $y$ over change in $x$.

So what can we do with this new formula, you ask? Well, what we would like to do is to make the change in $x$ (designated by $h$) equal to zero in order to find the function's slope at a single point. Exchanging $0$ for $h$ does not work well, however, since that would make the formula simply $\dfrac{f(x + 0) - f(x)}{0}$, which is not of much help ($\dfrac{0}{0} = ?$). Let us consult SageMath, though, and see if there is a way to factor out $h$ before setting it equal to zero. In a new cell, copy or type the following code.
︡4e4cd713-0e7f-42ff-8991-29283f0c27eb︡︡{"done":true,"md":"Rather than ignoring the relationship between the two points, as in the first form, this formula relies upon it. The symbol $y_2$ is now $f(x + h)$, and $y_1$ is $f(x)$. The major difference here, though, is that $x_2$ has been replaced by the first $x$ plus some change \"$h$\". The slope formula's premise still stands, however, as the new form does in fact calculate change in $y$ over change in $x$.\n\nSo what can we do with this new formula, you ask? Well, what we would like to do is to make the change in $x$ (designated by $h$) equal to zero in order to find the function's slope at a single point. Exchanging $0$ for $h$ does not work well, however, since that would make the formula simply $\\dfrac{f(x + 0) - f(x)}{0}$, which is not of much help ($\\dfrac{0}{0} = ?$). Let us consult SageMath, though, and see if there is a way to factor out $h$ before setting it equal to zero. In a new cell, copy or type the following code."}
︠f8b6ce8b-6d44-48e1-8105-0103b3d2914cs︠
def f(x):            # Set f(x) as x^3/2
    return (x^3)/2

var('x, h')          # Initialize variables x and h

(f(x + h) - f(x))/h  # Evaluate (f(x + h) - f(x))/h
︡e3ac77ed-5285-4e40-ab93-3d4651ee8e62︡︡{"stdout":"(x, h)\n","done":false}︡{"stdout":"1/2*((h + x)^3 - x^3)/h\n","done":false}︡{"done":true}
︠b514784f-18f8-401b-92e0-38188f6c9712i︠
%md
 The result should be $\dfrac{3x^2 + 3hx + h^2}{2}$. With $h$ still in the denominator, though, replacing it with zero would not be a good idea. Luckily, SageMath has a way for us to pull all variables from the denominator to the numerator, which is just what we need. In another cell, type and evaluate the following:
︡e4937a53-0efe-466b-9ff7-410fc796f6aa︡︡{"done":true,"md":" The result should be $\\dfrac{3x^2 + 3hx + h^2}{2}$. With $h$ still in the denominator, though, replacing it with zero would not be a good idea. Luckily, SageMath has a way for us to pull all variables from the denominator to the numerator, which is just what we need. In another cell, type and evaluate the following:"}
︠df810aab-25da-44b2-814b-c62e7d2b1e0bs︠
((f(x + h) - f(x))/h).rational_simplify()
︡5663b386-2101-456a-931d-4839bc9c1ff9︡︡{"stdout":"1/2*h^2 + 3/2*h*x + 3/2*x^2","done":false}︡{"stdout":"\n","done":false}︡{"done":true}
︠f37bbade-8dde-41aa-b78f-4d372d131765i︠
%md
The result should be $\dfrac{3x^2+3hx+h^2}{2}$. Now that $h$ is in the numerator, replacing it with zero will give us a formula for the function's slope at any value of $x$. To realize this result, add ".subs(h=0)" without the quotes to the end of rational_simplify() in the last entry and again evaluate the cell. And there you have it! By describing the change in $x$ as a number '$h$', we were able to simplify the formula for slope and replace $h$ with zero in order to find that the slope of the function's tangent line at any x-coordinate is equal to $\dfrac{3x^2}{2}$. This resulting expression is known as the **derivative** of $f(x) = \dfrac{x^3}{2}$. You'll learn more about derivatives in the next section, but for now you should know that a function's derivative measures rate of change at a point.

To complete what we had originally set out to do, plug in a value of $1$ for $x$, now, and you will see that the slope of the line tangent to the point $(1, \dfrac{1}{2})$ on $f(x) = \dfrac{x^3}{2}$ is $\dfrac{3}{2}$. This confirms our earlier experimentation with numerical analysis in addition to being an exact solution. If we were to write an equation for this tangent line in slope-intercept form, it would be

$y=\dfrac{3x}{2}-1$.
︡a6d5742b-24df-40ff-a86c-800a69d78e08︡︡{"done":true,"md":"The result should be $\\dfrac{3x^2+3hx+h^2}{2}$. Now that $h$ is in the numerator, replacing it with zero will give us a formula for the function's slope at any value of $x$. To realize this result, add \".subs(h=0)\" without the quotes to the end of rational_simplify() in the last entry and again evaluate the cell. And there you have it! By describing the change in $x$ as a number '$h$', we were able to simplify the formula for slope and replace $h$ with zero in order to find that the slope of the function's tangent line at any x-coordinate is equal to $\\dfrac{3x^2}{2}$. This resulting expression is known as the **derivative** of $f(x) = \\dfrac{x^3}{2}$. You'll learn more about derivatives in the next section, but for now you should know that a function's derivative measures rate of change at a point.\n\nTo complete what we had originally set out to do, plug in a value of $1$ for $x$, now, and you will see that the slope of the line tangent to the point $(1, \\dfrac{1}{2})$ on $f(x) = \\dfrac{x^3}{2}$ is $\\dfrac{3}{2}$. This confirms our earlier experimentation with numerical analysis in addition to being an exact solution. If we were to write an equation for this tangent line in slope-intercept form, it would be\n\n$y=\\dfrac{3x}{2}-1$."}
︠e0a5121f-436f-4257-8db0-c8f918c4f51bi︠
%md
It's very important to remember that the equation for a tangent line can always be written in slope-intercept or point-slope form; if you find that the equation for a tangent line is $y = x^{4x^2+e} + \sin(x)$ or some such extreme, something has gone (horribly) wrong. The slope of a tangent line will always be a constant.

You probably wouldn't be surprised to learn that this symbolic process involved a limit, specifically "the limit of $\dfrac{f(x + h) - f(x)}{h}$ as $h$ approaches zero." The slope that we found is also known as the **derivative** of $f(x)$ at $x=1$. Look at how the tangent line lies against the graph of $f(x) = \dfrac{x^3}{2}$:
︡a34ab27d-6d8a-49a8-a6cc-6defc0f86af6︡︡{"done":true,"md":"It's very important to remember that the equation for a tangent line can always be written in slope-intercept or point-slope form; if you find that the equation for a tangent line is $y = x^{4x^2+e} + \\sin(x)$ or some such extreme, something has gone (horribly) wrong. The slope of a tangent line will always be a constant.\n\nYou probably wouldn't be surprised to learn that this symbolic process involved a limit, specifically \"the limit of $\\dfrac{f(x + h) - f(x)}{h}$ as $h$ approaches zero.\" The slope that we found is also known as the **derivative** of $f(x)$ at $x=1$. Look at how the tangent line lies against the graph of $f(x) = \\dfrac{x^3}{2}$:"}
︠ce33b93e-e951-4d86-8eed-3d83f87f719b︠
# Plot the original function with its tangent line and a point to show where they touch
(plot(x^3/2, x, 0, 2)+plot(3*x/2-1, 0, 2, rgbcolor='red')+point((1, 1/2), \
	rgbcolor='black', pointsize=30)).show(xmin=0, xmax=2, ymin=-1, ymax=4)
︡61baedcb-b009-4b47-90b3-5b934b234afb︡︡{"once":false,"done":false,"file":{"show":true,"uuid":"99bd04da-1d0b-4eb2-82f4-dc9b4089bf1f","filename":"/projects/c71ef2fe-f1b2-482d-ab29-c91dba1e241a/.sage/temp/compute3-us/2552/tmp_0C08UF.svg"}}︡{"html":"<div align='center'></div>","done":false}︡{"done":true}
︠e927afe4-3a76-4d29-9507-733cab6ab40ai︠
%md
Now that we have an exact methodology for computing the slope of a tangent line, consider the function

$g(x)=\dfrac{3}{x}$

What is the equation for the line tangent to $(-2, g(-2))$? The slope of the tangent line can be found using the function's derivative:

$g'(x)=\underset{h\to0}{\rm{lim}}\dfrac{g(x+h)-g(x)}{h}=\underset{h\to0}{\rm{lim}}\dfrac{\dfrac{3}{x+h}-\dfrac{3}{x}}{h}=\underset{h\to0}{\rm{lim}}\dfrac{\dfrac{3x}{x^2+xh}-\dfrac{3x+3h}{x^2+xh}}{h}=\underset{h\to0}{\rm{lim}}\dfrac{-\dfrac{3h}{x^2+xh}}{h}=\underset{h\to0}{\rm{lim}}\dfrac{-3}{x^2}$

Plug in $-2$ for $x$, then write an equation for the tangent line:

$g'(-2)=-\dfrac{3}{(-2)^2}=-\dfrac{3}{4}$, so $y = -\dfrac{3}{4}x-3$

Here is another comparison:
︡877b4cf0-5bb2-45b4-ac07-002fac4196b2︡︡{"done":true,"md":"Now that we have an exact methodology for computing the slope of a tangent line, consider the function\n\n$g(x)=\\dfrac{3}{x}$\n\nWhat is the equation for the line tangent to $(-2, g(-2))$? The slope of the tangent line can be found using the function's derivative:\n\n$g'(x)=\\underset{h\\to0}{\\rm{lim}}\\dfrac{g(x+h)-g(x)}{h}=\\underset{h\\to0}{\\rm{lim}}\\dfrac{\\dfrac{3}{x+h}-\\dfrac{3}{x}}{h}=\\underset{h\\to0}{\\rm{lim}}\\dfrac{\\dfrac{3x}{x^2+xh}-\\dfrac{3x+3h}{x^2+xh}}{h}=\\underset{h\\to0}{\\rm{lim}}\\dfrac{-\\dfrac{3h}{x^2+xh}}{h}=\\underset{h\\to0}{\\rm{lim}}\\dfrac{-3}{x^2}$\n\nPlug in $-2$ for $x$, then write an equation for the tangent line:\n\n$g'(-2)=-\\dfrac{3}{(-2)^2}=-\\dfrac{3}{4}$, so $y = -\\dfrac{3}{4}x-3$\n\nHere is another comparison:"}
︠11138ebd-55f0-4bdb-940f-55f5cb05a040︠
# Plot the original function with its tangent line and a point to show where they touch.
(plot(3/x, x, -3, 0)+plot(-3*x/4-3, -3, 0, rgbcolor='red')+point((-2, -3/2), \
    rgbcolor='black', pointsize=30)).show(xmin=-3, xmax=0, ymin=-10, ymax=0)
︡2826a325-d33e-4328-9651-abd82bc1c637︡︡{"once":false,"done":false,"file":{"show":true,"uuid":"6345ceec-b452-4ed4-bff2-8bdd12091c37","filename":"/projects/c71ef2fe-f1b2-482d-ab29-c91dba1e241a/.sage/temp/compute3-us/1872/tmp_zcnpun.svg"}}︡{"html":"<div align='center'></div>","done":false}︡{"done":true}
︠69559dc9-1196-4ef5-a544-d4bdeea80f7ai︠
%md
## Practice Problems
Use the limit process to find the equation of the line tangent to the indicated point.

1) $f(x)=4x$ at $x=2$

2) $g(x)=-3x^2+2$ at $x=-1$

3) $x(t)=\dfrac{5}{t}+3$ at $t=5$
︡846aef2f-d004-4951-afb8-b2b5aada6071︡︡{"done":true,"md":"## Practice Problems\nUse the limit process to find the equation of the line tangent to the indicated point.\n\n1) $f(x)=4x$ at $x=2$\n\n2) $g(x)=-3x^2+2$ at $x=-1$\n\n3) $x(t)=\\dfrac{5}{t}+3$ at $t=5$"}
︠46576d63-cee2-4ff3-a3b6-a6fdbf358a13i︠
%md
<h4>To view answers, select this cell and paste it into your own sagews, and then double click on it</h4>
<!--
    1) The limit process yields a slope of 4; tangent line of y = 4*x (since 4*x was a straight line to begin with).
    2) The limit process yields a slope of 6; tangent line of y = 6*x+5.
    3) The limit process yields a slope of -1/5; tangent line of y = -x/5+5.
     -->
︡8a3af78f-794e-42da-aaac-7942850322a4︡︡{"done":true,"md":"<h4>To view answers, select this cell and paste it into your own sagews, and then double click on it</h4>\n<!--\n    1) The limit process yields a slope of 4; tangent line of y = 4*x (since 4*x was a straight line to begin with).\n    2) The limit process yields a slope of 6; tangent line of y = 6*x+5. \n    3) The limit process yields a slope of -1/5; tangent line of y = -x/5+5.\n     -->"}
︠f62ddaba-382f-4894-aa24-1170bd39a9dbi︠
%md
<center>[Previous: Supplement: Slant Asymptotes](Slant_Asymptotes.sagews) | [To Main](Introduction.sagews) | [Next: The Definition of the Derivative](The_Definition_of_the_Derivative.sagews)</center>
︡d8d0c223-51c5-423c-85fb-ab95dba83431︡{"done":true,"md":"<center>[Previous: Supplement: Slant Asymptotes](Slant_Asymptotes.sagews) | [To Main](Introduction.sagews) | [Next: The Definition of the Derivative](The_Definition_of_the_Derivative.sagews)</center>"}
︠d2707553-eb27-4d90-a6f3-ab51fccb701f︠









